@@ -39,20 +39,19 @@
 
 struct _GcalApplication
 {
-  GtkApplication  parent;
+  GtkApplication      parent;
 
-  GtkWidget      *window;
+  GtkWidget          *window;
 
-  GSettings      *settings;
-  GcalManager    *manager;
+  GcalManager        *manager;
+
+  GtkCssProvider     *provider;
+  GtkCssProvider     *colors_provider;
+
+  gchar              *uuid;
+  icaltimetype       *initial_date;
 
   GcalShellSearchProvider *search_provider;
-
-  GtkCssProvider *provider;
-  GtkCssProvider *colors_provider;
-
-  gchar          *uuid;
-  icaltimetype   *initial_date;
 };
 
 static void     gcal_application_create_new_event     (GSimpleAction           *new_event,
@@ -78,9 +77,6 @@ static void     gcal_application_quit                 (GSimpleAction           *
 G_DEFINE_TYPE (GcalApplication, gcal_application, GTK_TYPE_APPLICATION);
 
 static gboolean show_version = FALSE;
-static gboolean debug = FALSE;
-static gchar* date = NULL;
-static gchar* uuid = NULL;
 
 static GOptionEntry gcal_application_goptions[] = {
   {
@@ -90,17 +86,17 @@ static GOptionEntry gcal_application_goptions[] = {
   },
   {
     "debug", 'd', 0,
-    G_OPTION_ARG_NONE, &debug,
+    G_OPTION_ARG_NONE, NULL,
     N_("Enable debug messages"), NULL
   },
   {
     "date", 'd', 0,
-    G_OPTION_ARG_STRING, &date,
+    G_OPTION_ARG_STRING, NULL,
     N_("Open calendar on the passed date"), NULL
   },
   {
     "uuid", 'u', 0,
-    G_OPTION_ARG_STRING, &uuid,
+    G_OPTION_ARG_STRING, NULL,
     N_("Open calendar showing the passed event"), NULL
   },
   { NULL }
@@ -171,7 +167,6 @@ gcal_application_finalize (GObject *object)
 
   g_clear_object (&(self->provider));
   g_clear_object (&self->colors_provider);
-  g_clear_object (&self->settings);
 
   g_clear_object (&self->manager);
   g_clear_object (&self->search_provider);
@@ -218,18 +213,8 @@ gcal_application_activate (GApplication *application)
                                                          gcal_manager_get_system_timezone (self->manager));
         }
 
-      self->window = gcal_window_new_with_view_and_date (GCAL_APPLICATION (application),
-                                                         g_settings_get_enum (self->settings, "active-view"),
-                                                         self->initial_date);
-
-      g_signal_connect (self->window, "destroy", G_CALLBACK (gtk_widget_destroyed), &(self->window));
-
-      g_settings_bind (self->settings,
-                       "active-view",
-                       self->window,
-                       "active-view",
-                       G_SETTINGS_BIND_SET | G_SETTINGS_BIND_GET);
-
+      self->window = gcal_window_new_with_date (GCAL_APPLICATION (application), self->initial_date);
+      g_signal_connect (self->window, "destroy", G_CALLBACK (gtk_widget_destroyed), &self->window);
       gtk_widget_show (self->window);
     }
 
@@ -274,63 +259,63 @@ gcal_application_command_line (GApplication            *app,
                                GApplicationCommandLine *command_line)
 {
   GcalApplication *self;
-
-  GOptionContext *context;
-  gchar **argv;
-  GError *error;
-  gint argc;
+  GVariantDict *options;
+  GVariant *option;
+  const gchar* date = NULL;
+  const gchar* uuid = NULL;
+  gsize length;
 
   self = GCAL_APPLICATION (app);
-  argv = g_application_command_line_get_arguments (command_line, &argc);
-  context = g_option_context_new (N_("— Calendar management"));
-  g_option_context_add_main_entries (context, gcal_application_goptions, GETTEXT_PACKAGE);
+  options = g_application_command_line_get_options_dict (command_line);
 
-  error = NULL;
-  if (!g_option_context_parse (context, &argc, &argv, &error))
+  if (g_variant_dict_contains (options, "debug"))
+    gcal_log_init ();
+
+  if (g_variant_dict_contains (options, "uuid"))
     {
-      g_critical ("Failed to parse argument: %s", error->message);
-      g_error_free (error);
-      g_option_context_free (context);
-      return 1;
+      option = g_variant_dict_lookup_value (options, "uuid", G_VARIANT_TYPE_STRING);
+      uuid = g_variant_get_string (option, &length);
+
+      gcal_application_set_uuid (GCAL_APPLICATION (app), uuid);
+
+      g_variant_unref (option);
+    }
+  else if (g_variant_dict_contains (options, "date"))
+    {
+      struct tm result;
+
+      option = g_variant_dict_lookup_value (options, "date", G_VARIANT_TYPE_STRING);
+      date = g_variant_get_string (option, &length);
+
+      if (e_time_parse_date_and_time (date, &result) == E_TIME_PARSE_OK)
+        {
+          if (!self->initial_date)
+            self->initial_date = g_new0 (icaltimetype, 1);
+
+          *self->initial_date = tm_to_icaltimetype (&result, FALSE);
+          *self->initial_date = icaltime_set_timezone (self->initial_date,
+                                                       gcal_manager_get_system_timezone (self->manager));
+        }
+
+      g_variant_unref (option);
     }
 
+  g_application_activate (app);
+
+  return 0;
+}
+
+static gint
+gcal_application_handle_local_options (GApplication *app,
+                                       GVariantDict *options)
+{
   if (show_version)
     {
       g_print ("gnome-calendar: Version %s\n", PACKAGE_VERSION);
       return 0;
     }
 
-  if (debug)
-    gcal_log_init ();
-
-  if (uuid != NULL)
-    {
-      gcal_application_set_uuid (GCAL_APPLICATION (app), uuid);
-      g_clear_pointer (&uuid, g_free);
-    }
-  else if (date != NULL)
-    {
-      struct tm result;
-
-      if (e_time_parse_date_and_time (date, &result) == E_TIME_PARSE_OK)
-        {
-          if (self->initial_date == NULL)
-            self->initial_date = g_new0 (icaltimetype, 1);
-          *(self->initial_date) = tm_to_icaltimetype (&result, FALSE);
-
-          *(self->initial_date) = icaltime_set_timezone (self->initial_date,
-                                                         gcal_manager_get_system_timezone (self->manager));
-        }
-
-      g_clear_pointer (&date, g_free);
-    }
-
-  g_option_context_free (context);
-  g_strfreev (argv);
-
-  g_application_activate (app);
-
-  return 0;
+  return -1;
 }
 
 static gboolean
@@ -390,6 +375,7 @@ gcal_application_class_init (GcalApplicationClass *klass)
   application_class->activate = gcal_application_activate;
   application_class->startup = gcal_application_startup;
   application_class->command_line = gcal_application_command_line;
+  application_class->handle_local_options = gcal_application_handle_local_options;
 
   application_class->dbus_register = gcal_application_dbus_register;
   application_class->dbus_unregister = gcal_application_dbus_unregister;
@@ -398,10 +384,11 @@ gcal_application_class_init (GcalApplicationClass *klass)
 static void
 gcal_application_init (GcalApplication *self)
 {
-  self->settings = g_settings_new ("org.gnome.calendar");
+  g_application_add_main_option_entries (G_APPLICATION (self), gcal_application_goptions);
+
   self->colors_provider = gtk_css_provider_new ();
 
-  self->manager = gcal_manager_new_with_settings (self->settings);
+  self->manager = gcal_manager_new ();
   g_signal_connect_swapped (self->manager, "source-added", G_CALLBACK (process_sources), self);
   g_signal_connect_swapped (self->manager, "source-changed", G_CALLBACK (process_sources), self);
 
@@ -513,6 +500,14 @@ gcal_application_new (void)
                        NULL);
 }
 
+/**
+ * gcal_application_get_manager:
+ * @self: a #GcalApplication
+ *
+ * Retrieves the #GcalManager of the application.
+ *
+ * Returns: (transfer none): a #GcalManager
+ */
 GcalManager*
 gcal_application_get_manager (GcalApplication *self)
 {
@@ -521,14 +516,6 @@ gcal_application_get_manager (GcalApplication *self)
   return self->manager;
 }
 
-GSettings*
-gcal_application_get_settings (GcalApplication *self)
-{
-  g_return_val_if_fail (GCAL_IS_APPLICATION (self), NULL);
-
-  return self->settings;
-}
-
 void
 gcal_application_set_uuid (GcalApplication *self,
                            const gchar     *app_uuid)
