@@ -18,6 +18,7 @@
 
 #define G_LOG_DOMAIN "GcalEvent"
 
+#include "gconstructor.h"
 #include "gcal-event.h"
 #include "gcal-utils.h"
 #include "gcal-recurrence.h"
@@ -134,6 +135,39 @@ enum {
   N_PROPS
 };
 
+
+/*
+ * GcalEvent cache
+ */
+
+static GHashTable *event_cache = NULL;
+
+G_DEFINE_CONSTRUCTOR (init_event_cache_map);
+
+static void
+init_event_cache_map (void)
+{
+  event_cache = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
+}
+
+G_DEFINE_DESTRUCTOR (destroy_event_cache_map);
+
+static void
+destroy_event_cache_map (void)
+{
+  GList *events;
+
+  /* Destroy all events */
+  events = g_hash_table_get_values (event_cache);
+  g_list_free_full (events, g_object_unref);
+
+  g_hash_table_destroy (event_cache);
+}
+
+/*
+ * Auxiliary methods
+ */
+
 static GTimeZone*
 get_timezone_from_ical (ECalComponentDateTime *comp)
 {
@@ -428,6 +462,10 @@ gcal_event_finalize (GObject *object)
 {
   GcalEvent *self = (GcalEvent *)object;
 
+  g_debug ("Removing '%s' (%p) from cache", self->uid, self);
+
+  g_hash_table_remove (event_cache, self->uid);
+
   g_clear_pointer (&self->dt_start, g_date_time_unref);
   g_clear_pointer (&self->dt_end, g_date_time_unref);
   g_clear_pointer (&self->timezone, g_time_zone_unref);
@@ -437,7 +475,7 @@ gcal_event_finalize (GObject *object)
   g_clear_pointer (&self->color, gdk_rgba_free);
   g_clear_object (&self->component);
   g_clear_object (&self->source);
-  g_clear_pointer (&self->recurrence, gcal_recurrence_free);
+  g_clear_pointer (&self->recurrence, gcal_recurrence_unref);
 
   G_OBJECT_CLASS (gcal_event_parent_class)->finalize (object);
 }
@@ -791,12 +829,36 @@ gcal_event_new (ESource        *source,
                 ECalComponent  *component,
                 GError        **error)
 {
-  return g_initable_new (GCAL_TYPE_EVENT,
-                         NULL,
-                         error,
-                         "source", source,
-                         "component", component,
-                         NULL);
+  GcalEvent *event;
+  g_autofree gchar *uuid;
+
+  uuid = get_uuid_from_component (source, component);
+
+  if (g_hash_table_contains (event_cache, uuid))
+    {
+      g_debug ("Using cached value for %s", uuid);
+
+      event = g_hash_table_lookup (event_cache, uuid);
+      gcal_event_set_component_internal (event, component);
+      g_object_ref (event);
+    }
+  else
+    {
+      event = g_initable_new (GCAL_TYPE_EVENT,
+                              NULL,
+                              error,
+                              "source", source,
+                              "component", component,
+                              NULL);
+
+      if (event)
+        {
+          g_debug ("Adding %s to the cache", event->uid);
+          g_hash_table_insert (event_cache, event->uid, event);
+        }
+    }
+
+  return event;
 }
 
 /**
@@ -1651,7 +1713,7 @@ gcal_event_set_recurrence (GcalEvent      *self,
   comp = gcal_event_get_component (self);
   icalcomp = e_cal_component_get_icalcomponent (comp);
 
-  g_clear_pointer (&self->recurrence, gcal_recurrence_free);
+  g_clear_pointer (&self->recurrence, gcal_recurrence_unref);
   self->recurrence = gcal_recurrence_copy (recur);
 
   prop = icalcomponent_get_first_property (icalcomp, ICAL_RRULE_PROPERTY);
