@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,9 +18,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "gcal-search-view.h"
+#define G_LOG_DOMAIN "GcalSearchView"
 
+#include "gcal-debug.h"
 #include "gcal-event.h"
+#include "gcal-search-view.h"
 #include "gcal-utils.h"
 
 #include <glib/gi18n.h>
@@ -295,7 +297,7 @@ make_row_for_event (GcalSearchView *view,
 {
   GDateTime *local_datetime;
   GDateTime *date_start;
-  GdkPixbuf *pixbuf;
+  cairo_surface_t *surface;
 
   GtkWidget *row;
   GtkWidget *grid;
@@ -309,10 +311,10 @@ make_row_for_event (GcalSearchView *view,
   GtkWidget *image;
 
   /* get event color */
-  pixbuf = gcal_get_pixbuf_from_color (gcal_event_get_color (event), 16);
+  surface = gcal_get_surface_from_color (gcal_event_get_color (event), 16);
 
   /* make an image of the color */
-  image = gtk_image_new_from_pixbuf (pixbuf);
+  image = gtk_image_new_from_surface (surface);
 
   /* grid & box*/
   row = gtk_list_box_row_new ();
@@ -395,7 +397,7 @@ make_row_for_event (GcalSearchView *view,
   gtk_widget_show_all (row);
 
   g_clear_pointer (&local_datetime, g_date_time_unref);
-  g_object_unref (pixbuf);
+  g_clear_pointer (&surface, cairo_surface_destroy);
 
   return row;
 }
@@ -412,10 +414,16 @@ make_row_for_event (GcalSearchView *view,
 static void
 update_view (GcalSearchView *view)
 {
+  GCAL_ENTRY;
+
   if (view->no_results_timeout_id != 0)
     g_source_remove (view->no_results_timeout_id);
 
-  view->no_results_timeout_id = g_timeout_add (NO_RESULT_TIMEOUT, (GSourceFunc) show_no_results_page, view);
+  view->no_results_timeout_id = g_timeout_add (NO_RESULT_TIMEOUT,
+                                               (GSourceFunc) show_no_results_page,
+                                               view);
+
+  GCAL_EXIT;
 }
 
 /**
@@ -433,6 +441,8 @@ gcal_search_view_do_search (gpointer user_data)
   GcalSearchView *view;
   gchar *search_query;
 
+  GCAL_ENTRY;
+
   view = GCAL_SEARCH_VIEW (user_data);
 
   search_query = g_strdup_printf ("(contains? \"%s\" \"%s\")",
@@ -440,31 +450,30 @@ gcal_search_view_do_search (gpointer user_data)
                                              view->query ? view->query : "");
 
   if (!view->subscribed)
-        {
-          g_autoptr (GDateTime) now, start, end;
+    {
+      g_autoptr (GDateTime) now, start, end;
 
-          now = g_date_time_new_now_local ();
-          start = g_date_time_add_years (now, -5);
-          end = g_date_time_add_years (now, 5);
+      now = g_date_time_new_now_local ();
+      start = g_date_time_add_years (now, -5);
+      end = g_date_time_add_years (now, 5);
 
-          gcal_manager_set_search_subscriber (view->manager, E_CAL_DATA_MODEL_SUBSCRIBER (view),
-                                              g_date_time_to_unix (start),
-                                              g_date_time_to_unix (end));
+      gcal_manager_set_search_subscriber (view->manager, E_CAL_DATA_MODEL_SUBSCRIBER (view),
+                                          g_date_time_to_unix (start),
+                                          g_date_time_to_unix (end));
 
-          /* Mark the view as subscribed */
-          view->subscribed = TRUE;
-        }
+      /* Mark the view as subscribed */
+      view->subscribed = TRUE;
+    }
 
-      /* update internal current time_t */
-      view->current_utc_date = time (NULL);
+  /* update internal current time_t */
+  view->current_utc_date = time (NULL);
 
-      gcal_manager_set_query (view->manager, search_query);
+  gcal_manager_set_query (view->manager, search_query);
 
-      view->search_timeout_id = 0;
-      g_free (search_query);
+  view->search_timeout_id = 0;
+  g_free (search_query);
 
-
-  return G_SOURCE_REMOVE;
+  GCAL_RETURN (G_SOURCE_REMOVE);
 }
 
 static void
@@ -787,13 +796,14 @@ gcal_search_view_search (GcalSearchView *view,
                          const gchar    *field,
                          const gchar    *query)
 {
+  GCAL_ENTRY;
+
   g_clear_pointer (&view->query, g_free);
   g_clear_pointer (&view->field, g_free);
 
   if (view->search_timeout_id != 0)
     g_source_remove (view->search_timeout_id);
 
-
   /* Only perform search on valid non-empty strings */
   if (query && g_utf8_strlen (query, -1) >= 3)
     {
@@ -808,5 +818,7 @@ gcal_search_view_search (GcalSearchView *view,
     }
 
   update_view (view);
+
+  GCAL_EXIT;
 }
 
