@@ -32,6 +32,7 @@
 #define MAX_MINUTES     (7 * MINUTES_PER_DAY)
 
 #define gcal_clear_datetime(dt) g_clear_pointer (dt, g_date_time_unref)
+#define gcal_clear_timeout(pp) { if (pp && *pp) { g_source_remove (*pp); *pp = 0; } }
 
 /**
  * GcalWindowViewType:
@@ -54,6 +55,18 @@ typedef enum
   GCAL_WINDOW_VIEW_SEARCH,
 } GcalWindowViewType;
 
+typedef enum
+{
+    GCAL_WEEK_DAY_INVALID   = 0,
+    GCAL_WEEK_DAY_SUNDAY    = 1 << 0,
+    GCAL_WEEK_DAY_MONDAY    = 1 << 1,
+    GCAL_WEEK_DAY_TUESDAY   = 1 << 2,
+    GCAL_WEEK_DAY_WEDNESDAY = 1 << 3,
+    GCAL_WEEK_DAY_THURSDAY  = 1 << 4,
+    GCAL_WEEK_DAY_FRIDAY    = 1 << 5,
+    GCAL_WEEK_DAY_SATURDAY  = 1 << 6
+} GcalWeekDay;
+
 GType           icaltime_get_type                               (void)            G_GNUC_CONST;
 
 gint            datetime_compare_date                           (GDateTime             *dt1,
@@ -140,7 +153,13 @@ gboolean        should_change_date_for_scroll                   (gdouble
 gboolean        is_source_enabled                               (ESource               *source);
 
 gboolean        ask_recurrence_modification_type                (GtkWidget             *parent,
-                                                                 ECalObjModType        *modtype,
+                                                                 GcalRecurrenceModType *modtype,
                                                                  ESource               *source);
 
+gboolean        is_workday                                      (guint	                day);
+
+GList*          filter_event_list_by_uid_and_modtype            (GList                 *widgets,
+                                                                 GcalRecurrenceModType  mod,
+                                                                 const gchar           *uid);
+
 #endif // __GCAL_UTILS_H__
